libsimple

Function set_dict

pub fn set_dict(
    connection: &Connection,
    directory: impl AsRef<Path>,
) -> Result<()>
Available on crate feature jieba only.
Only need to call once for each connection, but must call this function before using sql jieba_query.

You should call release_dict first.